Crate nidus_cache

Crate nidus_cache 

Official cache adapter for Nidus applications.

This crate is installed separately from the core nidus facade so cache backend dependencies are only compiled by applications that choose them.

Structs

CacheConfig
Cache provider configuration shared by cache backends.
CacheKey
Namespaced cache key helper.
MokaCacheBuilder
Builder for a Moka local in-memory cache provider.
MokaCacheProvider
Nidus provider wrapping a Moka local in-memory cache.

Enums

CacheError
Error returned by cache adapter operations.

Type Aliases

Result
Result type used by cache adapter operations.