pub struct CacheConfig { /* private fields */ }Expand description
Cache provider configuration shared by cache backends.
Implementations
Sourceimpl CacheConfig
impl CacheConfig
Sourcepub fn namespace(self, namespace: impl Into<String>) -> Self
pub fn namespace(self, namespace: impl Into<String>) -> Self
Sets the namespace prefix applied to logical cache keys.
Sourcepub fn time_to_live(self, time_to_live: Duration) -> Self
pub fn time_to_live(self, time_to_live: Duration) -> Self
Sets the default time to live for cache entries.
Sourcepub fn max_capacity(self, max_capacity: u64) -> Self
pub fn max_capacity(self, max_capacity: u64) -> Self
Sets the maximum weighted entry capacity.
Sourcepub fn namespace_value(&self) -> Option<&str>
pub fn namespace_value(&self) -> Option<&str>
Returns the configured namespace.
Sourcepub fn time_to_live_value(&self) -> Option<Duration>
pub fn time_to_live_value(&self) -> Option<Duration>
Returns the configured default time to live.
Sourcepub fn max_capacity_value(&self) -> Option<u64>
pub fn max_capacity_value(&self) -> Option<u64>
Returns the configured maximum capacity.