pub struct MokaCacheBuilder { /* private fields */ }Expand description
Builder for a Moka local in-memory cache provider.
Implementations
Sourceimpl MokaCacheBuilder
impl MokaCacheBuilder
Sourcepub fn config(self, config: CacheConfig) -> Self
pub fn config(self, config: CacheConfig) -> Self
Replaces the builder config.
Sourcepub fn namespace(self, namespace: impl Into<String>) -> Self
pub fn namespace(self, namespace: impl Into<String>) -> Self
Sets the namespace prefix applied to logical cache keys.
Sourcepub fn time_to_live(self, time_to_live: Duration) -> Self
pub fn time_to_live(self, time_to_live: Duration) -> Self
Sets the default time to live for cache entries.
Sourcepub fn max_capacity(self, max_capacity: u64) -> Self
pub fn max_capacity(self, max_capacity: u64) -> Self
Sets the maximum weighted entry capacity.
Sourcepub fn build(self) -> MokaCacheProvider
pub fn build(self) -> MokaCacheProvider
Builds a Moka cache provider.